SystemOrganization addCategory: #'Pier-SW2-Sw1Features'!

PRExternalLink subclass: #PRCustomLink
	instanceVariableNames: ''
	classVariableNames: 'StringToUrlBlocks'
	poolDictionaries: ''
	category: 'Pier-SW2-Sw1Features'!

!PRCustomLink commentStamp: 'JohnBorden 8/4/2011 20:59' prior: 0!
A PRCustomLink is an external link which can be be used to create links to calculatable pages.  It is generally modified in Smalltalk.  Examples of things that can be added are:
	PRCustomLink addConversion: [:aString | (('cc######' match: aString) and: [(aString copyFrom: 3 to: 8) isAllDigits])
			ifTrue: [(aString copyFrom: 3 to: 8) asInteger < 94477
				ifTrue: ['http://cmidom1srv/cmi/formsarchive.nsf/ReqNumber/' , (aString asLowercase)]
				ifFalse: ['http://cmidom1srv/cmi/forms.nsf/ReqNumber/' , (aString asLowercase)]]].
	PRCustomLink addConversion: [:aString | (('cc######dr' match: aString) and: [(aString copyFrom: 3 to: 8) isAllDigits])	
			ifTrue: ['http://cmidom1srv/cmi/forms.nsf/ReqNumber/' , (aString asLowercase)]].
	PRCustomLink addConversion: [:aString | (('xc######' match: aString) and: [(aString copyFrom: 3 to: 8) isAllDigits])
			ifTrue: ['http://cmidom1srv/cmi/cingular.nsf/ReqNumber/' , (aString asLowercase)]].
	PRCustomLink addConversion: [:aString | (('Case #*-#*' match: aString)
			and: [| numbers | numbers := (aString copyFrom: 6 to: aString size) findTokens: '-'.  numbers size = 2 and: [(numbers contains: [:aSubString | aSubString isAllDigits not]) not]])	
				ifTrue: ['http://cmiweb1/champs/Subcase_Details.asp?idn=' , (aString copyFrom: 6 to: aString size)]].
	PRCustomLink addConversion: [:aString | (('Case ######*' match: aString) and: [(aString copyFrom: 6 to: 11) isAllDigits])
			ifTrue: ['http://cmiweb1/champs/Case_Details.asp?idn=' , (aString copyFrom: 6 to: 11)]].
	PRCustomLink addConversion: [:aString | ('\\cmifs01\*' match: aString) 
			ifTrue: ['file:///' , (aString copy translateWith: ((String withAll: Character allCharacters) at: $\ asciiValue + 1 put: $/; yourself))]].
	PRCustomLink addConversion: [:aString | (('doc *' match: aString) and: [(aString copyFrom: 5 to: aString size) isAllDigits and: [aString size > 5]])
			ifTrue: [aString size > 9
				ifTrue: ['http://docloader/Docloader/docloader.aspx?action=view&foldernum=', (aString copyFrom: 5 to: 							aString size)]
				ifFalse: ['http://Docloader/Docloader/docloader.aspx?action=view&docnum=', (aString copyFrom: 5 to: aString size)]]]
		
		
		Instance Variables
		Class Variables
			StringToUrlBlocks - <OrderedCollection of single argument blocks>  - conversion for links into addresses.!

!PRCustomLink class methodsFor: 'accessing' stamp: 'JCB 2/13/2009 14:26'!
addConversion: aBlock
	aBlock argumentCount = 1
			ifFalse: [self error: 'This expects a one argument block'].
	self stringToUrlBlocks add: aBlock! !

!PRCustomLink class methodsFor: 'private-testing' stamp: 'JCB 2/24/2009 13:46'!
conversions: aCollection
	aCollection isCollection ifFalse: [self error: 'The argument must be a collection.'].
	StringToUrlBlocks := aCollection! !

!PRCustomLink class methodsFor: 'testing' stamp: 'JCB 2/13/2009 14:27'!
isValidReference: aString
	^ self stringToUrlBlocks
		contains: [:block | (block value: aString) notNil]! !

!PRCustomLink class methodsFor: 'accessing' stamp: 'JCB 2/13/2009 14:27'!
stringToUrlBlocks
	StringToUrlBlocks isNil
		ifTrue: [StringToUrlBlocks := OrderedCollection new].
	^ StringToUrlBlocks! !

!PRCustomLink methodsFor: 'accessing-dynamic' stamp: 'JCB 2/13/2009 14:33'!
url
	^ (self class stringToUrlBlocks
		detect: [:e | (e value: self reference) notNil])
		value: self reference! !

Object subclass: #Pier1ToPier2Converter
	instanceVariableNames: 'kernel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-SW2-Sw1Features'!

!Pier1ToPier2Converter commentStamp: '<historical>' prior: 0!
Pier1ToPier2Converter is used to convert an imported pier 1 kernel to pier 2 syntax, it replaces html tags with {{{<tag>}}} for a set of known tags (see #verbatimToMatch).

An example of how this can be used to convert pages:

| converter persistency |
persistency := PRKernel instances anyOne persistency.
PRKernel instances anyOne persistency: PRNullPersistency new.
converter := Pier1ToPier2Converter new kernel: (PRKernel instances anyOne).
PRKernel instances anyOne root enumerator everything do: [:page | Pier1ToPier2Converter convertPage: page].
PRKernel instances anyOne persistency: persistency

Before running this, one should check that '{{{' should not be found.!

!Pier1ToPier2Converter class methodsFor: 'as yet unclassified' stamp: 'JCB 4/29/2011 23:42'!
convertPage: aPage
	| new |
	new := self new.
	new kernel: aPage kernel.
	new convertPage: aPage! !

!Pier1ToPier2Converter methodsFor: 'accessing' stamp: 'JCB 3/31/2011 22:04'!
contextForStructure: aStructure command: aCommand
	| context |
	context := PRContext kernel: self kernel structure: aStructure command: aCommand.
	context propertyAt: #user put: (context kernel users select: [ :e | e isSuperuser ]) anyOne.
	^ context! !

!Pier1ToPier2Converter methodsFor: 'actions' stamp: 'JCB 3/31/2011 22:03'!
convertPage: aStructure
	| command context document |
	aStructure hasDocument ifFalse: [^self].
	command := PREditCommand new.
	context := self contextForStructure: aStructure command: command.
	document := PRPage descriptionDocument fromString: (self convertString: aStructure document text).
	command write: document using: PRPage descriptionDocument.
	command execute! !

!Pier1ToPier2Converter methodsFor: 'actions' stamp: 'JCB 5/6/2011 22:25'!
convertString: aString
	^ String new: aString size
		streamContents: [ :lines | 
			aString lines
				do: [ :line | 
					line first = $=
						ifTrue: [ lines nextPutAll: line ]
						ifFalse: [ lines nextPutAll: (self verbatimToMatch copy: line translatingMatchesUsing: [ :match | '{{{' , match , '}}}' ]) ] ]
				separatedBy: [ lines cr ] ]! !

!Pier1ToPier2Converter methodsFor: 'accessing' stamp: 'JCB 3/31/2011 06:40'!
kernel
	^ kernel! !

!Pier1ToPier2Converter methodsFor: 'accessing' stamp: 'JCB 3/31/2011 06:40'!
kernel: aKernel
	kernel := aKernel! !

!Pier1ToPier2Converter methodsFor: 'accessing' stamp: 'JohnBorden 8/4/2011 21:00'!
verbatimToMatch
	"Commonly used HTML on pier 1 pages."
	
	^ '<br[^>]*>|<hr[^>]*>|<ol[^>]*>|<ul[^>]*>|<li[^>]*>|</ul>|</ol>|<blockquote[^>]*>|</blockquote>|<span[^>]*>|</span>|<div[^>]*>|</div>|&#[0-9]*;|&lt;|&gt;' asRegexIgnoringCase! !

PRNavigationWidget subclass: #PRPathNavigationWidget
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-SW2-Sw1Features'!

!PRPathNavigationWidget commentStamp: 'JohnBorden 8/4/2011 20:56' prior: 0!
PRPathNavigationWidget is a widget that displays the link path to the current structure, as links (like / parent / child / thisPage).
!

!PRPathNavigationWidget class methodsFor: 'accessing' stamp: 'JCB 3/1/2009 21:10'!
label
	^ 'Link Path'! !

!PRPathNavigationWidget methodsFor: 'rendering' stamp: 'JCB 3/1/2009 21:07'!
renderParents: aCollection on: html
	| active path |
	active := self isActive: aCollection first.
	path := active and: [ self selected parents includes: aCollection first ].
	html anchor
		class: 'path' if: path;
		class: 'active' if: active;
		goto: (self context structure: aCollection first);
		with: '/'.
	aCollection allButFirst do: [:e | self renderItem: e on: html] separatedBy: [html text: '/']! !

TestCase subclass: #Pier1ToPier2ConverterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-SW2-Sw1Features'!

!Pier1ToPier2ConverterTest methodsFor: 'tests' stamp: 'JCB 4/30/2011 22:46'!
testConvertAmpersandString
	self
		assert:
			(Pier1ToPier2Converter new convertString: 'This contains & as well as &#42; in it.')
				= 'This contains & as well as {{{&#42;}}} in it.'.
	self
		assert:
			(Pier1ToPier2Converter new convertString: 'This contains &LT; as well as &gT; in it.')
				= 'This contains {{{&LT;}}} as well as {{{&gT;}}} in it.'! !

!Pier1ToPier2ConverterTest methodsFor: 'tests' stamp: 'JCB 4/30/2011 22:47'!
testConvertString
	self assert: (Pier1ToPier2Converter new convertString: '<br />') = '{{{<br />}}}'.
	self
		assert:
			(Pier1ToPier2Converter new
				convertString:
					'Change this <br /> string
= This should not change <br /> because preformatted
another string')
				=
					'Change this {{{<br />}}} string
= This should not change <br /> because preformatted
another string'.
	self
		assert:
			(Pier1ToPier2Converter new convertString: '<div class="First">text</div> and <div class="Second">text</div>')
				= '{{{<div class="First">}}}text{{{</div>}}} and {{{<div class="Second">}}}text{{{</div>}}}'	! !
